import React, { Component } from 'react';

export class TodoApp extends Component {

  constructor(props) {
    super(props);
    this.state = { items: [], newItem: "" };
  }

  render = () => {
    return (
      <div>
        <h1>To-Do List</h1>
        {this.renderItems()}
        <p>Check the item to mark it completed. Click delete to remove it.</p>
        <div>
          <label htmlFor='item-input'>New item: </label>
          <input type="text" value={this.state.newItem}
            onChange={this.doNewItemChange} id='item-input' />
          <button type="button"
            onClick={this.doAddClick}>Add Item</button>
        </div>
      </div>
    );
  }

  renderItems = () => {
    if (this.state.items.length === 0) {
      return <p>No items. Add one to get started!</p>
    }

    const items = [];
    for (let i = 0; i < this.state.items.length; i++) {
      const item = this.state.items[i];
      items.push(
        <li key={i}>
          <input type="checkbox" id={"check" + i} checked={item.completed}
            onChange={evt => this.doItemToggleComplete(evt, i)} />
          <label htmlFor={"check" + i}>
            {item.completed ? <s>{item.name}</s> : item.name}
          </label>{" "}
          <button onClick={evt => this.doItemRemove(evt, i)}>Delete</button>
        </li>
      )
    }
    return <ul>{items}</ul>;
  };

  doNewItemChange = (evt) => {
    this.setState({ newItem: evt.target.value });
  }

  doAddClick = (evt) => {
    const name = this.state.newItem.trim();
    if (name.length == 0)
      return;

    const items = this.state.items.concat([{ name: name, completed: false }]);
    this.setState({ items: items, newItem: "" });
  }

  doItemToggleComplete = (evt, index) => {
    const item = this.state.items[index];

    const items = this.state.items.slice(0, index)
      .concat([{ name: item.name, completed: !item.completed }])
      .concat(this.state.items.slice(index + 1));

    this.setState({ items: items });
  };

  doItemRemove = (evt, index) => {
    const items = this.state.items.slice(0, index)
      .concat(this.state.items.slice(index + 1));

    this.setState({ items: items });
  }
}
